@@ -653,11 +653,12 @@ class MenuContext(InteractionContext):
         logger,
     ):
         super().__init__(_http=_http, _json=_json, _discord=_discord, logger=logger)
+        self.name = self.command = self.invoked_with = _json["data"]["name"]  # This exists.
         self.context_type = _json["type"]
         self._resolved = self.data["resolved"] if "resolved" in self.data.keys() else None
         self.target_message = None
         self.target_author = None
-        self.target_id = self.data["target_id"]
+        self.target_id = self.data["target_id"] if "target_id" in self.data.keys() else None
 
         if self._resolved is not None:
             try:
@@ -676,8 +677,11 @@ class MenuContext(InteractionContext):
             try:
                 if self.guild and self._resolved["members"]:
                     _auth = [auth for auth in self._resolved["members"]][0]
+                    # member and user return the same ID
+                    _neudict = self._resolved["members"][_auth]
+                    _neudict["user"] = self._resolved["users"][_auth]
                     self.target_author = discord.Member(
-                        data=self._resolved["members"][_auth],
+                        data=_neudict,
                         state=self.bot._connection,
                         guild=self.guild,
                     )
